# Capitalisation des Unités d'Enseignement en BUT

## Principe général

Une formation est constituée d'une succession de semestres (dans ScoDoc un
"semestre" peut avoir une durée quelconque, mais pour le BUT ce sont de vrais
semestres), eux-mêmes divisés en Unités d'Enseignement (UEs).

Les UEs sont constituées de modules (ressources et SAÉs en BUT). Les UEs sont
*capitalisables* et associées à des crédits académiques (ECTS). Lorsqu'un
étudiant interrompt ses études ou redouble, il conserve ses UEs capitalisées.

ScoDoc prend en compte cela par différents mécanismes:

- lorsqu'un étudiant redouble dans la même formation, ses UEs capitalisées sont
  automatiquement prises en compte. L'étudiant peut choisir de refaire une UE
  capitalisée. Dans ce cas, ScoDoc prendra automatiquement en compte celle ayant
  la meilleure note. Il peut aussi choisir de ne pas refaire cette UE (voir plus
  loin).
- Il arrive que les programmes évoluent d'une année sur l'autre (changement de
  version, réformes). ScoDOc permet d'indiquer si des UEs de différents
  programmes sont équivalentes et peuvent se capitaliser.
- Enfin, ScoDoc permet d'enregistrer la validation d'une UE obtenue par ailleurs
  (par exemple dans un autre établissement suite à un transfert, à l'étranger,
  etc.).

## Formations ScoDoc et UEs

Chaque UE possède un code interne ScoDoc que l'on peut modifier via la page
d'édition des programmes:

<img src="/screens/ue-edit-code.png" width="70%"
alt="Modification du code interne d'une UE">

On peut utiliser un code quelconque, y compris celui donné dans un autre
logiciel comme Apogée. En bas de cette même page, ScoDoc affiche la liste des
UEs ayant le même code, afin de vérifier facilement la compatibilité:

<img src="/screens/ue-edit-code-equiv.png" width="70%"
alt="UEs partageant le même code">

Ne pas confondre ce code d'UE interne avec le code Apogée, qui n'est utilisé que pour
les exports de résultats.

## La moyenne d'UE capitalisée

La note (moyenne) de l'UE est enregistrée ("photo instantanée") au moment de la
saisie de la décision de jury la concernant (si cette décision est
"capitalisante"), afin d'être utilisée dans la suite de la scolarité de
l'étudiant (redoublement, ou construction de RCUE inter-annuels).

Attention, il faut veiller à ne jamais modifier les notes après décision du
jury, c'est une évidence qui n'est pas toujours respectée. En effet, outre le
fait que le jury serait alors sans valeur, si la moyenne d'une UE capitalisée
change après son enregistrement, on observera des discordances entre les valeurs
capitalisées (PV de jury, etc) et celles calculées et affichées sur les relevés
de notes.

ScoDoc essaye de décourager cela:

- verrouillage de semestres conseillé immédiatement après le jury;
- nombreux avertissements lors des tentatives de saisies de notes s'il existe
  une décision de jury.

Au besoin, il est toujours possible, avec les droits adéquats, après
déverrouillage du semestre et avec en principe l'autorisation du président du
jury (...) de resaisir la décision, afin d'enregistrer la nouvelle moyenne.

## Exemple BUT avec UE capitalisée

Soit une formation BUT, ici R&T, avec 3 UE. Certaines ressources (comme R101) sont communes à
deux ou trois UEs.

<img src="/fig/but-uescap-coefs.png" width="25%">

L'étudiant "Mael REDOUBLE" a redoublé sa première année, mais avait capitalisé
l'UE 1 de S1. Son parcours s'affiche ainsi:

<img src="/fig/but-uescap-fiche.png" width="60%">

Son bulletin montre l'UE 1 actuelle (moyenne 8,32/20) et celle capitalisée
(moyenne 10,36/20):
<img src="/fig/but-uescap-bul-avant.png" width="70%">

Il décide de ne pas refaire cette UE1. Pour cela, on le désinscrit de l'UE (menu
**Inscriptions** / **Gérer les inscriptions aux UEs et modules**).

<img src="/fig/but-uescap-desincr.png" width="40%">

Maintenant, son UE1 capitalisée apparait seule sur son bulletin.

Dans cet exemple, la ressource `R101` (commune) est rattachée à l'UE 1 (mais ce
rattachement technique n'a pas de conséquences pratiques). L'étudiant reste bien
sûr inscrit à `R101` (et doit suivre ses cours), puisque cette ressource
intervient dans les autres UE non capitalisées.

S'il y a des ressources dont les notes ne contribuent qu'à l'UE1, l'étudiant
peut ne pas les suivre: il faut alors le désincrire sélectivement au niveau du
tableau de bord module.

C'est dans cet exemple le cas pour la SAÉ `SAE11`.

<img src="/fig/but-uescap-inscrmodule.png" width="30%">

## Gestion des semestres à l'étranger

Certains étudiants suivent parfois des semestres à l'extérieur de leur
établissement d'origine.

Le jury a décidé d'une équivalence entre certaines UEs suivies à l'extérieur et
celles du la formation d'origine.

Il est important de reporter ces résultats dans ScoDoc afin que celui-ci puisse
tenir compte des UEs validés, de leurs ECTS, et en fin de cursus délivrer
correctement le diplôme.

Une façon simple de traiter ce cas et de le gérer comme les transferts
d'étudiants en cours de cursus: à l'inscription dans le semestre $S_{n+1}$, on
va enregistrer les validations d'UEs *antérieures* obtenues dans le semestre
$S_n$, que celui ci est été effectué à l'étranger (équivalence des UEs) ou dans
un autre établissement (transfert).

Note: il y aura alors un "trou" dans le cursus, par exemple $S_1, S_2, S_3, S_5$,  si
$S_4$ est effectué à l'étranger.

Dans cet exemple, l'étudiant a suivi son semestre $S_4$ à l'extérieur: il
n'apparait pas sur sa fiche. Après inscription en S5, on valide ses UEs de S4.

<img src="/screens/validation-ues-anterieures-menu.png" width="70%"
alt="Menu validation UEs antérieures">

Lors de la saisie d'une validation d'UE antérieure, on indique son code jury (en
général `ADM` si il n'y a pas eu de problèmes), et la note obtenue (qui pourra
servir comme UE capitalisée ou sur les avis de poursuite d'études):

<img src="/screens/validation-ues-anterieures-saisie.png" width="70%"
alt="Formulaire validation UEs antérieures">
