
# Mise en œuvre de Bonus/Malus sur les notes

Scodoc permet l'application de bonus/malus sur les moyennes générales (formation
non BUT) et/ou les moyennes d'UE. Il existe deux mécanismes complémentaires pour
cela:

## Les bonus sport/culture

Le bonus sport/culture permet de calculer un modificateur sur la moyenne
générale (formations non BUT) ou sur chacune des UE (BUT). La valeur du bonus
est calculée à partir d'un note sur 20 et au moyen d'une formule propre à chaque
IUT.

## Les modules de malus

Il est fréquent d'introduire des pénalités ou *malus* sur les moyennes calculées
à partir des notes. Par exemple, dans certains établissements, l'absence de
l'étudiant à des activités obligatoires peut entrainer des points de pénalités.
Inversement, certaines activités facultatives pourraient donner lieu à des
bonifications.


Pour gérer cela ScoDoc propose de déclarer des modules de *malus*: les notes de
malus sont directement *soustraites* à la moyenne générale de l'UE à laquelle
elles appartiennent. Contrairement aux
notes ordinaires dans ScoDoc, les notes de malus sont toujours comprises entre
-20 et +20. Une note de malus de 1 va diminuer la moyenne de l'UE de 1. Une note
négative augmenterait cette moyenne. Les moyennes d'UE sont toujours comprises
entre 0 et 20: si l'application du malus donne une note supérieure à 20 (ou
inférieure à zéro), elle est ramenée à 20 (ou à zéro).

- A la différence du bonus sport/culture, ces modifications ne portent pas
    uniformément sur la totalité des UEs. Si on veut que le malus s'applique à
    plusieurs UE, il faudra créer plusieurs modules de malus.

- De plus, aucune formule n'est implémentée et on saisira directement la valeur
  du malus (ou bonus)

- Les valeurs saisies ne sont pas affichées telles quelles sur les bulletins.
  Seule la somme des modificateurs est affichée (à coté de l'UE sur laquelle
  elle porte)

- Il est possible de décrire plusieurs évaluations (donc plusieurs saisies):
  c'est la moyenne (non pondérée) des valeurs de malus qui sera appliquée à l'UE.

- La valeur saisie peut être négative (et donnera alors un bonus);
    l'affichage est mis à jour en conséquence. C'est donc la possibilité
    d'inclure un bonus donc la valeur n'est pas calculée par la formule
    configurée (cf. [Intégration de la formule](#intégration-de-la-formule)).

## Comparatif bonus/malus

Le tableau ci-dessous résume les différences entre les bonus sport/culture et
les modules de malus.

| Critère                              | Bonus Sport/culture                               | Module de Malus                            |
|:-------------------------------------|:--------------------------------------------------|:-------------------------------------------|
| **Structure**                        | UE Spécifique et modules (type standard) attachés | Module spécifique (type malus)             |
| **Valeur du bonus/malus**            | Calculé à partir d'une note                       | Saisie directe                             |
| **Application sur toutes les UE**    | Automatique                                       | Autant de modules que d'UE modifiées       |
| **Application sur une seule UE**     | Impossible                                        | Un module par UE modifiée                  |                                   |
| **Modification**                     | Bonus seulement                                   | Malus ou Bonus                             |
| **Affichage**                        | Affichage du bonus et du détail                   | Affichage du bonus/malus seulement         |
| **Cumul de plusieurs modificateurs** | voir [les remarques](#remarques)                  | Déclarer une évaluation par type de modif. |

## Bonus Sport & Culture

### Intégration de la règle de calcul

Il faut tout d'abord régler ScoDoc pour utiliser la formule propre à votre
établissement. Cela est fait une fois pour toutes et pour tous les départements
et affectera les semestres pour lesquels un bonus sport est utilisé.

Pour cela l'administrateur du site (lui seul y est autorisé) doit aller sur la
page de configuration de Scodoc (bandeau en haut de la page d'accueil)

![configuration](screens/BonusMalus_01.png)

puis, dans la section '`Calcul des "bonus" définis par l'établissement`', sélectionner
l'établissement dans le dans le menu déroulant.

![choix-bonus-sport](screens/BonusMalus_02.png)

Si l'établissement n'apparaît pas:

1. L'item '`Bonus "Direct"`' permet de saisir directement la valeur du
   modificateur (après un calcul préalable hors scodoc)

2. Vous pouvez demander la création de la formule spécifique à votre
   établissement sur le serveur discord en précisant:
    - Le nom de votre établissement,
    - l'extrait du règlement intérieur qui décrit cette bonification, (celui ci
      apparaîtra dans l'encadré explicatif)
    - Quelques cas d'usages (pour les tests)

### Ajout d'UE Sport/culture

#### Bonus sport/culture

L'opération suivante consiste à ajouter dans le programme l'UE Sport/Culture.

1. Éditer la formation. Pour cela vous pouvez passer par le menu `SEMESTRE >
   Voir la formation...` (ceci permet d'aller dans le programme associé au
   semestre.

2. Ajouter une UE 'Sport/Culture',
    - Donner un titre (en y incluant le semestre visé - toutes les UEs d'une
      formation doivent avoir leur propre nom et il y aura aussi probablement
      des UE sport pour les autres semestres)
    - Idem pour l'acronyme
    - Choisissez le Type `Sport/Culture (points bonus)`
    - Indiquez 0 ECTS (obligatoire bien que cette valeur n'ait pas d'importance)
   ![ajout-UE-sport](screens/BonusMalus_03.png)

3. Ajouter un module à l'UE sport et l'attacher à l'UE Sport du semestre
    Attention ! ce module est un module standard (pas un module de malus, ni une
   ressource, ni une SAÉ) ![module-sport](screens/BonusMalus_04.png)

## Modules de Malus

Il faut ajouter à la formation un ou plusieurs modules de malus. Le module est
rattaché à une UE et modifiera la moyenne de cette UE.

1. Entrer dans le semestre,

2. activer le menu `SEMESTRE > Modifier le semestre`
   ![modifier-le-semestre](screens/BonusMalus_05.png)

A ce niveau, vous pouvez soit:

- ajouter les modules malus en une seule fois pour toutes les UEs par le lien
  `ajouter un module de malus dans chaque UE su S...`
  ![ajout-global-malus](screens/BonusMalus_11.png)

- Ou, si une des UEs ne demande pas l'application d'un malus, ajouter seulement
  les modules nécessaires en les créant un par un:
  ![ajout-simple-malus](screens/BonusMalus_12.png) en précisant le type `Malus`
  et en l'attachant à l'UE concernée.
  ![ajout-simple-malus-détail](screens/BonusMalus_13.png)

L'étape [Ajout d'UE et de module
Sport/Culture](#ajout-due-sportculture-etou-de-module-de-malus) doit être faite
lors de la conception d'un programme, mais n'a pas a être réitérée lors de la
création d'une nouvelle version d'un programme avec UE sport.

Une fois le module créé (et ajouté à un semestre), on peut y déclarer une
évaluation et saisir les notes de bonus/malus. Ces notes sont par défaut *à prise
en compte immédiate*, auquel cas il n'est pas nécessaire de saisir des notes de malus
pour tous les étudiants.


## Application à un semestre

Quel que soit le type de bonus utilisé, le semestre concerné doit  intégrer le
ou les modules créés précédemment, que ce soit les modules appartenant à l'UE
sport/culture ou les modules de malus.

Si la création du semestre est postérieur à la modification du programme, ou si
le semestre résulte du clonage d'un semestre déjà configuré, les éléments de
bonus/malus sont déjà pris en compte et on peut passer directement à la partie
[inscription des
étudiants](finaliser-linscription-des-étudiants-concernés-si-inscription-sélective)

Dans le cas contraire (le bonus n'avait pas été prévu au départ et doit être
ajouté en cours de semestre) la manipulation suivante permet l'application des
éléments de bonus/malus aux au semestre existant:

### Stratégies d'inscription

Dans tous les cas de figure, l'objectif est d'inscrire aux modules de
bonus/malus au moins les étudiants qui en bénéficient. On a deux stratégies
possibles:

1. Inscription de tous les étudiants du semestre (inscription générale) 
   et attribuer la note `EXC`aux étudiants non concernés. Stratégie à
   éviter pour le bonus sport/culture afin d'éviter l'affichage d'une
   section bonus vide dans les bulletins des étudiants non concernés.

2. N'inscrire que les étudiants concernés (inscription sélective). **Note**: si
   le bonus sport/culture peut résulter de plusieurs activités (par exemple
   sport et LV2) on peut tout de même être amené à placer des `EXC`.

### Application des modifications du programme à un semestre existant

1. Entrer dans le semestre,

2. activer le menu `SEMESTRE > Modifier le semestre`
   ![modifier-le-semestre](screens/BonusMalus_05.png)

3. Les éléments de bonus/malus apparaissent mais ne sont pas activés
   ![activation-module-sport](screens/BonusMalus_06.png)

4. Activer les modules utilisés et y affecter les étudiants selon la stratégie
   choisie (inscription générale: tous, inscription sélective: aucun)

5. Valider les modifications opérées

### Finaliser l'inscription des étudiants concernés (si inscription sélective)

**Note**: cette finalisation peut être faite juste avant la saisie des notes de sport.

1. Se placer dans le module bonus/malus
  ![sélection-module-sport](screens/BonusMalus_07.png)
  ou
  ![sélection-module-malus](screens/BonusMalus_14.png)

2. Affiner les inscriptions en cliquant sur le lien de modification:
   ![inscriptions-module-sport](screens/BonusMalus_08.png)

### Saisie des notes

- Créer si besoin une évaluation dans le module courant

- Saisir les notes des étudiants.
  - Pour un bonus sport/culture : la valeur à saisir (valeur du bonus, note sur
    20, ...) dépend de la règle de l'établissement.
  - Pour un module de malus Saisir directement la valeur du *malus* (pour que
    l'étudiant bénéficie d'un bonus, entrer une valeur négative)

#### Remarques

- Le `Bonus "direct"` autorise des bonus de 0 à 20 mais plafonne les notes d'UE à 20
- On peut avoir plusieurs évaluations dans le module sport: dans ce cas ScoDoc
    calcul la note de module comme habituellement (y compris en prenant en
    compte les éventuels coefficients), puis calcul la valeur du bonus à partir
    de cette note de module. On ne peut donc pas 'cumuler' (un bonus sport et un
    bonus LV2 par exemple) par ce biais.
- On peut avoir plusieurs modules attachées à l'UE sport. Dans ce cas, ScoDoc
    calcule le bonus qui produirait chacun de ces modules et les additionne.
    Dans ce cas, les bonus sont cumulés, mais:

  - Cette méthode n'est applicable que si les formules de calcul de chacun des bonus cumulés sont identiques.

  - Dans tous les cas, les notes d'UE restent plafonnées entre 0 et 20.

#### Exemple

On a déclaré dans une UE sport 2 modules:

- `Sport` alimenté par 2 évaluations (Sport et Autre),

- `LV2` alimenté par une seule évaluation

Un étudiant participe aux deux activités et obtient les notes suivantes:
![notes-sport-exemple](screens/BonusMalus_09.png)

Le calcul effectué par ScoDoc est le suivant:

- Calcul de la moyenne du module `Sport` ( 13.00 (coef. 1) et 10.00 (coef. 2)):
  résultat : 11.00 soit un bonus de 1 pt x 5% (calcul Villetaneuse) = 0.05 points

- Calcul de la moyenne `LV2`: 15.00 (une seule note) soit un bonus de 5 points x 5% = 0.25 points

- Le bonus total sera donc de 0.30 points

- L'UE1 qui est de base à 19.80 sera donc amenée à 20 (plafond) grâce au bonus de 0.30
  ![notes-sport-exemple-UE1](screens/BonusMalus_10.png)
    Les autres UE bénéficient du bonus de 0.30 points

## Affichages

La forme que prend l'affichage du ou des bonus/malus varie en fonction des circonstances:

- Aucun bonus/malus

- Cas 1: Bonus sport/culture uniquement

- Cas 2: Malus

- Cas 3: Bonus formulé comme malus négatif

Les bonus/malus sont affichés principalement sur:

### Table récapitulative des notes

Deux colonnes sont affichées pour chaque UE. pour indiquer le bonus
sport/culture d'une part et le malus (ou bonus complémentaire) comme indiqué
ci-dessous ![Table-des-notes](screens/BonusMalus_15.png)

### Relevé de notes web d'un étudiant (y compris sur la passerelle)

La description de l'UE inclut la valeur des bonus et malus (même si nulle) comme
indiqué dans les exemple ci-dessous. La moyenne avant altération figure en bas
tandis que la valeur supérieure (en gras) affiche la moyenne après bonus/malus
(plafonnée si besoin):

###### Cas 1. aucun bonus malus
![relevé-web-cas1](screens/BonusMalus_16.png)
###### Cas 2. Bonus sport/culture uniquement
![relevé-web-cas2](screens/BonusMalus_17.png)
###### Cas 3. Malus
![relevé-web-cas3](screens/BonusMalus_18.png)
###### Cas 4. Malus négatif
![relevé-web-cas4](screens/BonusMalus_19.png)

### Relevé de notes en version pdf

###### Cas 1. aucun bonus malus
![relevé-pdf-cas1](screens/BonusMalus_20.png)
###### Cas 2. Bonus sport/culture uniquement
![relevé-pdf-cas2](screens/BonusMalus_21.png)
###### Cas 3. Malus
![relevé-pdf-cas3](screens/BonusMalus_22.png)
###### Cas 4. Malus négatif
![relevé-pdf-cas4](screens/BonusMalus_23.png)


!!! note "Voir aussi"

    - [Calcul des notes](CalculNotes.md#bonus-sportculture)
    - [Tutoriel vidéo: ajouter un bonus sport&culture](https://www.youtube.com/watch?v=SVbjuDpq-lI)
    - [FAQ](FAQ.md)
    - [Contacts](Contact.md)

