# Les principaux objets de ScoDoc

Nous introduisons ici les principaux objets manipulés par ScoDoc.

## Départements

Un serveur ScoDoc peut gérer un nombre quelconque de départements. Les
départements sont entièrement séparés, à l'exception des comptes utilisateurs
(un secrétaire ou une enseignante peuvent intervenir dans plusieurs
départements). Les étudiants et les formations sont rattachés à un et un seul
département.

Lorsqu'un utilisateur se connecte, il voit en bleu les liens vers les
départements dans lesquels il a le droit d'aller.

![sco-accueil-0223.png](screens/sco-accueil-0223.png)

## Semestre

Un *semestre* représente une session d'un dispositif de formation. La plupart des
formations LMD sont structurées en années scolaires de deux semestres. Dans
ScoDoc, un "semestre" peut avoir une durée quelconque, il peut aussi bien s'agir
une action de formation continue d'une semaine que d'une formation sur un an.

Saisie des dates de début et fin d'un semestre:
![sco-dates-semestre.png](screens/sco-dates-semestre.png)

Les semestre a un ou plusieurs (co)responsables, utilisateurs ayant des droits
particuliers, dont ceux de modifier la liste des modules d'enseignement à
suivre, de nommer les enseignants, etc. Les responsables de semestres sont
souvent appelés *directeurs ou directrices des études*.

Un semestre a un ensemble d'étudiants inscrits.

Le tableau de bord du semestre indique notamment la liste des modules qui y sont
proposés:
![sco-formsemestre-status.png](screens/sco-formsemestre-status.png)


## Formations (programmes pédagogiques)

Un semestre utilise une *formation* (programme pédagogique) qui définit les
unités d'enseignement (UE), modules, coefficients, crédits académiques, etc.
Pour en savoir plus, voir [programmes pédagogiques et versions](Formations.md).

Exemple: une formation de *Bachelor Universitaire de Technologie* (BUT):
![sco-formation-but.png](screens/sco-formation-but.png)

## Modules

Un *module* représente un dispositif pédagogique, typiquement un ensemble de
cours, travaux dirigés, travaux pratiques, mais il peut aussi s'agir d'un
projet, d'un stage, ou de tout ensemble d'activités.

Un module a un enseignant responsable (typiquement le chargé de cours) et des
des enseignants associés (typiquement les chargés de TD).

Un sous-ensemble des étudiants inscrits au semestre peut être inscrit au module.

En BUT, les modules représentent les *ressources* et les SAÉs.

Le tableau de bord d'un module permet d'y inscrire les étudiants, modifier les
enseignants, créer des évaluations et y saisir des notes.
Exemple: une ressource de BUT
![sco-modimpl-status.png](screens/sco-modimpl-status.png)

## Évaluations

Une *évaluation* est un dispositif pédagogique produisant une note par étudiant.
Les notes sont numériques, mais dans les formations en approche par compétences
(APC), les évaluations peuvent être associées à des *apprentissages critiques*.

Pour en savoir plus:

- [Les évaluations](Evaluation.md)
- [Calcul des notes](CalculNotes.md)
- [Bachelor Universitaire de Technologie (BUT)](BUT.md)

Exemple: modification d'une évaluation
![sco-evaluation-edit.png](screens/sco-evaluation-edit.png)

## Étudiants

Un étudiant peut être créé individuellement par formulaire, ou bien importé via
une feuille de calcul (par exemple Excel), ou, via un connecteur API, importé
depuis un autre système (Apogée, Pégase, annuaire...).

Les étudiants sont rattachés à un et un seul département (en cas de transfert,
le créer dans l'autre département). Chaque étudiant peut être inscrit à un
nombre quelconque de semestres (en général, à un instant $t$, l'étudiant a un
seul semestre en cours, mais il arrive que les semestres suivis se chevauchent).

La fiche de l'étudiant rassemble de nombreuses informations: données d'état
civil, coordonnées, photographie, semestres suivis et leurs résultats résumés,
annotations, etc. Ces informations peuvent être modifiées dans ScoDoc. Les accès
et les droits de modification sont contrôlés par des autorisations spécifiques,
tous les utilisateurs n'ont pas accès aux mêmes vues.

Exemple: extrait de la fiche d'un étudiant
![sco-fiche-etud.png](screens/sco-fiche-etud.png)

## Groupes et partitions

Les étudiants d'un semestre peuvent être répartis dans des groupes.

Chaque *partition* d'un semestre défini un ensemble de groupes: par exemple, les
la partition des groupes de TD, ou la partition des projets tuteurés.

On peut à tout moment créer une partition, y créer des groupes, y placer ou
déplacer des étudiants.

Exemple: l'éditeur de partitions
![sco-partition-edit.png](screens/sco-partition-edit.png)



## Utilisateurs

ScoDoc gère des comptes utilisateur, et associe à chacun des rôles spécifiques,
eux-mêmes associés à des permissions (droits d'accès). ce système permet de
hiérarchiser l'accès aux informations et opérations sensibles (modification de
résultats, inscriptions, éditions de procès-verbaux, etc.).

- [Rôles et permissions dans ScoDoc](ConfigPermissionsDept.md)
- [Gestion des utilisateurs dans ScoDoc](AdminUsers.md)

### Administrateur de département

L'administrateur d'un département (typiquement le responsable de formation ou
chef de département, ou bien une personne de confiance) possède des droits
étendus sur son département (rassemblés dans le rôle `AdminDept`). Il peut
notamment modifier les formations, mettre en place des semestres, créer des
comptes utilisateurs.

### Super-administrateur

Le super-administrateur est un utilisateur ayant des droits d'accès complet au
logiciel. Ce compte ne doit pas être utilisé pour autre chose que le paramétrage
global. Il est le seul à avoir accès aux pages de configuration, accessibles via
la page d'accueil:

![sco-config-generale.png](screens/sco-config-generale.png)

## Assiduité et justificatifs

Voir [Suivi de l'assiduité](Assiduites.md).


!!! note "Voir aussi"

    - [Guide utilisateur](GuideUtilisateur.md)
    - [FAQ](FAQ.md)
    - [Contacts](Contact.md)
